@@ -1,10 +1,10 @@
 import io
 from typing import Union
-
 from .apis import upload_file
+from .types import PILImage
 
 
-def convert_file(file: Union[str, io.IOBase]) -> str:
+def convert_file(file: Union[str, io.IOBase, PILImage]) -> str:
     if not file:
         return ""
 
@@ -16,4 +16,9 @@ def convert_file(file: Union[str, io.IOBase]) -> str:
         # path to file
         file = open(file, "rb")
 
+    if callable(getattr(file, "save", None)):
+        file_path = "/tmp/img.png"
+        file.save(file_path)
+        file = open(file_path, "rb")
+
     return upload_file(file)
