@@ -2,8 +2,9 @@ from hackerforms.socket import send, receive
 from hackerforms.generated.widget_schema import WidgetSchema
 from hackerforms.page_response import PageResponse
 from hackerforms.validation import validate_widget_props
+from .reactive import Reactive
 
-from typing import Callable, Dict
+from typing import Callable, Dict, Union, List
 
 
 class Page(WidgetSchema):
@@ -15,35 +16,86 @@ class Page(WidgetSchema):
     user and collect the answers.
     """
 
-    def __init__(self):
+    def __init__(
+        self,
+        actions: Union[str, List[str]] = "Next",
+        columns: float = 1,
+        validate: Callable = None,
+        end_program: bool = False,
+        reactive_polling_interval=0,
+        initial_payload: Dict = None,
+    ):
         super().__init__()
+        self.__actions = actions
+        self.__columns = columns
+        self.__validate = validate
+        self.__end_program = end_program
+        self.__reactive_polling_interval = reactive_polling_interval
+        self.__initial_payload = initial_payload
 
     def run(
-        self, actions="Next", columns: float = 1, validate: Callable = None
+        self,
+        actions: Union[str, List[str]] = "Next",
+        columns: float = 1,
+        validate: Callable = None,
+        end_program: bool = False,
+        reactive_polling_interval=0,
+        initial_payload: Dict = None,
     ) -> Dict:
         """Run the form
 
         Args:
             button_text: The text of the button that is used to submit the form
             columns: The number of columns of the form
+            end_program: End program whilst showing this page, making this an end page
+            reactive_polling_interval: Interval to poll and rerender reactive slots, in seconds (0 to disable)
 
         Returns:
             The form result as a dict with the keys being the key of the input and the value being the value of the input
         """
 
+        actions = actions if actions != "Next" else self.__actions
+        columns = columns if columns != 1 else self.__columns
+        end_program = end_program if end_program != False else self.__end_program
+        reactive_polling_interval = (
+            reactive_polling_interval
+            if reactive_polling_interval != 0
+            else self.__reactive_polling_interval
+        )
+        initial_payload = (
+            initial_payload if initial_payload != None else self.__initial_payload
+        )
+        validate = validate if validate != None else self.__validate
+
+        if initial_payload:
+            for widget in self.widgets:
+                if not isinstance(widget, Reactive) and widget.key in initial_payload:
+                    widget.initial_value = initial_payload[widget.key]
+
         widgets_json = self.__get_validated_page_widgets_json(self.convert_answer({}))
 
         if self.__is_progress_screen():
-            self.__send_form_message(widgets=widgets_json, columns=columns, actions=[])
+            self.__send_form_message(
+                widgets=widgets_json,
+                columns=columns,
+                actions=[],
+                end_program=end_program,
+                reactive_polling_interval=reactive_polling_interval,
+            )
             return
 
         self.__send_form_message(
             widgets=widgets_json,
             columns=columns,
-            actions=self.__actions_property(actions),
+            actions=self.__actions_property(actions, end_program),
+            end_program=end_program,
+            reactive_polling_interval=reactive_polling_interval,
         )
         response: Dict = self.__user_event_messages(validate=validate)
 
+        if end_program:
+            exit()
+
         return PageResponse(
             self.convert_answer(response["payload"]),
             response.get("action"),
@@ -72,8 +124,10 @@ class Page(WidgetSchema):
             validate_widget_props(widget)
         return widgets_json
 
-    def __actions_property(self, actions):
-        if isinstance(actions, list):
+    def __actions_property(self, actions, end_page):
+        if end_page:
+            return []
+        elif isinstance(actions, list):
             return actions
         elif actions is None:
             return []
@@ -97,13 +151,17 @@ class Page(WidgetSchema):
 
         return {"status": validation_status, "message": validation_message}
 
-    def __send_form_message(self, widgets, actions, columns):
+    def __send_form_message(
+        self, widgets, actions, columns, end_program, reactive_polling_interval
+    ):
         send(
             {
                 "type": "form",
                 "widgets": widgets,
                 "columns": columns,
                 "actions": actions,
+                "endProgram": end_program,
+                "reactivePollingInterval": reactive_polling_interval,
             }
         )
 
